=============
Extended
=============

This package contains a number of functions that are python implementations of wolfram language functions

Contents
-------------


Changelog
-------------

0.0.0 The start



